var Utility = /** @class */ (function () {
    function Utility() {
    }
    Utility.convertToHumanReadable = function (bytes, isDiskSpace) {
        if (isDiskSpace === void 0) { isDiskSpace = false; }
        var thresh = isDiskSpace ? 1000 : 1024;
        if (Math.abs(bytes) < thresh)
            return bytes + ' B';
        var units = ['KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];
        var u = -1;
        do {
            bytes /= thresh;
            ++u;
        } while (Math.abs(bytes) >= thresh && u < units.length - 1);
        return bytes.toFixed(1) + ' ' + units[u];
    };
    Utility.encode = function (n) {
        var output = '';
        while (n > 0) {
            var p = n % 32;
            n = Math.floor(n / 32);
            output = Utility._keyStr.charAt(p) + output;
        }
        if (output.length < 6) {
            var half = Math.floor(output.length / 2);
            return output.substr(0, half) + '-' + output.substr(half);
        }
        else {
            if (output.length < 10) {
                output = '00000'.substr(0, 10 - output.length) + output;
            }
            return output.substr(0, 5) + '-' + output.substr(5);
        }
    };
    Utility.genCheckDigits = function (n) {
        var digits = n.toString();
        var cs = 0;
        var xs = 0;
        for (var i = 0; i < digits.length; i++) {
            var d = parseInt(digits.charAt(i));
            cs += d;
            xs ^= d;
        }
        return (cs % 10).toString() + (xs % 10).toString();
    };
    Utility.encodeMac = function (input) {
        var clean = input.toUpperCase().replace(/[^0-9A-Z]/gi, '');
        var n = parseInt(clean, 16);
        return Utility.encode(n) + '-' + Utility.genCheckDigits(n);
    };
    Utility.encodeGUID = function (input) {
        var sncode = '';
            if(!isNaN(input))
                input = input.toString();
            if(input.length < 12){
                for(var i; i < 12 - input.length; i++){
                    sncode+= '0';
                }
            }
            for(var i in input){
                var c = input.charCodeAt(i).toString();
                sncode += c;
            }
            sncode = parseInt(sncode, 16) % 0xffffffffffff;
            return Utility.encode(sncode) + '-' + Utility.genCheckDigits(sncode);
    };
    Utility.genSnCheckDigits = function (digits) {
        var cs = 0;
        var xs = 0;
        for (var i = 0; i < digits.length; i++) {
            var d = parseInt(digits.charAt(i), 36);
            cs += d;
            xs ^= d;
        }
        xs = xs % 36;
        cs = cs % 36;
        return (cs.toString(36) + xs.toString(36)).toUpperCase();
    };
    Utility.encodeSN = function (input) {
        if (input.indexOf(':') > -1) {
            input = input.split(':')[1]; // handle case where it comes in like this - SN:L8G793004192
        }
        var clean = input.toUpperCase().replace(/[^0-9A-Z]/gi, '');
        if (clean.length != 12) {
            clean = ('000000000000000' + clean).substr(-12);
        }
        var encoded = clean + Utility.genSnCheckDigits(clean);
        return encoded.substr(0, 6) + '-' + encoded.substr(6, 6) + '-' + encoded.substr(12);
    };
    Utility.decode = function (input) {
        input = input.toUpperCase().replace(/[^0-9A-Z]/gi, '');
        var n = 0;
        for (var i = 0; i < input.length - 2; i++) {
            n = n * 32;
            n = n + Utility._keyStr.indexOf(input.charAt(i));
        }
        return n;
    };
    Utility.validate = function (input) {
        if (input) {
            try {
                if ((input.length < 14) || (input.length > 16)) {
                    return false;
                }
                var clean = input.toUpperCase().replace(/[^0-9A-Z]/gi, '');
                if ((clean.length < 12) || (clean.length > 14)) {
                    return false;
                }
                var cd1, cd2;
                cd1 = clean.substr(-2);
                if (clean.length == 14) {
                    cd2 = Utility.genSnCheckDigits(clean.substr(0, 12));
                }
                else {
                    cd2 = Utility.genCheckDigits(Utility.decode(clean));
                }
                return (cd1 == cd2);
            }
            catch (err) {
                console.error(err);
                return false;
            }
        }
        else {
            return false;
        }
    };
    Utility.validateTenant = function (input) {
        if (input) {
            try {
                if (input.length != 9) {
                    return false;
                }
                var clean = input.toUpperCase().replace(/[^0-9A-Z]/gi, '');
                if (clean.length != 7) {
                    return false;
                }
                var cd1 = clean.substr(clean.length - 2, 2);
                var cd2 = Utility.genCheckDigits(Utility.decode(input));
                return (cd1 == cd2);
            }
            catch (err) {
                console.error(err.stack);
                return false;
            }
        }
        else {
            return false;
        }
    };
    Utility.encodeTenant = function (t) {
        var n = (t * 1415) ^ 7654321;
        return Utility.encode(n) + '-' + Utility.genCheckDigits(n);
    };
    Utility.decodeTenant = function (tenant) {
        var n = Utility.decode(tenant);
        return Math.floor((n ^ 7654321) / 1415);
    };
    Utility.parseEnum = function (enumeration, src, defValue) {
        var enString = enumeration;
        var enNumber = enumeration;
        if (typeof src === 'undefined') {
            return defValue;
        }
        // Numeric src           
        var num = parseInt(src);
        if (!isNaN(num)) {
            var str = enNumber[num];
            if (str !== undefined)
                return num;
        }
        else {
            var temp = enString[src];
            if (temp !== undefined)
                return temp;
        }
        return defValue;
    };
    Utility.getParametersFromUrl = function () {
        var query = "?";
        if (location.search !== "") {
            query = location.search.substr(1);
        }
        else if (location.hash !== "") {
            query = location.hash.substr(1);
        }
        var result = {};
        //console.info("Parsing parameters: " + query);
        query.split("&").forEach(function (part) {
            var item = part.split("=");
            result[item[0]] = decodeURIComponent(item[1]);
            //console.info(item[0] + '=' + result[item[0]] + '\n');
        });
        return result;
    };
    Utility.encodeURIObject = function (obj) {
        return encodeURIComponent(JSON.stringify(obj));
    };
    Utility.decodeURIObject = function (arg) {
        if (arg) {
            try {
                return JSON.parse(decodeURIComponent(arg));
            }
            catch (e) {
                console.error(e);
            }
        }
        return {};
    };
    Utility.ajaxCall = function (options) {
        $.ajax(options);
    };
    Utility.checkProvisioning = function (provisioningToken, webService, callback) {
        console.info("Checking for provisioning of " + provisioningToken + " on " + webService);
        var successHandler = function (data) {
            console.info(JSON.stringify(data));
            if (data.provisioned) {
                return callback(data);
            }
            else {
                return callback();
            }
        };
        var errorHandler = function (data) {
            console.error("Error - " + JSON.stringify(data));
            return callback();
        };
        var url = webService + ("/v1/check?pt=" + provisioningToken);
        if (url.indexOf('http:') === 0) {
            url += "&rnd=" + Math.random(); // Brightsign caches http too agressively
        }
        var options = {
            url: url,
            success: successHandler,
            error: errorHandler,
            type: "GET",
            dataType: "json"
        };
        Utility.ajaxCall(options);
    };
    Utility.waitForProvisioning = function (provisioningToken, candidates, callback) {
        var nextCandidate = 0;
        var timing = 20000 / candidates.length; // Total checking loop of 20 seconds
        var checkNext = function () {
            if (nextCandidate >= candidates.length) {
                nextCandidate = 0;
            }
            Utility.checkProvisioning(provisioningToken, candidates[nextCandidate++], function (p) {
                if (p) {
                    return callback(p);
                }
                setTimeout(checkNext, timing);
            });
        };
        checkNext(); // Do the first check immediately
    };
    Utility.nextTick = function (callback) {
        setTimeout(callback, 0);
    };
    Utility.createCookie = function (name, value, days) {
        if (days) {
            var date = new Date();
            date.setTime(date.getTime() + (days * 24 * 60 * 60 * 1000));
            var expires = "; expires=" + date.toUTCString();
        }
        else
            var expires = "";
        document.cookie = name + "=" + value + expires + "; path=/";
    };
    Utility.readCookie = function (name) {
        var nameEQ = name + "=";
        var ca = document.cookie.split(';');
        for (var i = 0; i < ca.length; i++) {
            var c = ca[i];
            while (c.charAt(0) == ' ')
                c = c.substring(1, c.length);
            if (c.indexOf(nameEQ) == 0)
                return c.substring(nameEQ.length, c.length);
        }
        return null;
    };
    Utility.eraseCookie = function (name) {
        Utility.createCookie(name, "", -1);
    };
    /**
     * Convert a base64 string in a Blob according to the data and contentType.
     *
     * @param b64Data {String} Pure base64 string without contentType
     * @param contentType {String} the content type of the file i.e (image/jpeg - image/png - text/plain)
     * @param sliceSize {Int} SliceSize to process the byteCharacters
     * @see http://stackoverflow.com/questions/16245767/creating-a-blob-from-a-base64-string-in-javascript
     * @return Blob
     */
    Utility.b64toBlob = function (b64Data, contentType, sliceSize) {
        contentType = contentType || '';
        sliceSize = sliceSize || 512;
        var byteCharacters = atob(b64Data);
        var byteArrays = [];
        for (var offset = 0; offset < byteCharacters.length; offset += sliceSize) {
            var slice = byteCharacters.slice(offset, offset + sliceSize);
            var byteNumbers = new Array(slice.length);
            for (var i = 0; i < slice.length; i++) {
                byteNumbers[i] = slice.charCodeAt(i);
            }
            var byteArray = new Uint8Array(byteNumbers);
            byteArrays.push(byteArray);
        }
        var blob = new Blob(byteArrays, { type: contentType });
        return blob;
    };
    Utility.forgeTxCookie = function (cms, tenant) {
        var result = "";
        for (var i = 0; i < Constants.txCookieDomains.length; i++) {
            if (cms.indexOf(Constants.txCookieDomains[i]) >= 0) {
                result = "Set-Cookie: tx=" + tenant + "; path=/; domain=" + Constants.txCookieDomains[i] + "; HttpOnly";
            }
        }
        return result;
    };
    Utility.getHostname = function (url) {
        var hostname;
        //find & remove protocol (http, ftp, etc.) and get hostname
        if (url.indexOf("://") > -1) {
            hostname = url.split('/')[2];
        }
        else {
            hostname = url.split('/')[0];
        }
        //find & remove port number
        hostname = hostname.split(':')[0];
        //find & remove "?"
        hostname = hostname.split('?')[0];
        return hostname;
    };
    Utility._keyStr = '0BCD1EF2GH3JK4LM5NP6QR7ST8VW9XYZ'; //<== DO NOT MODIFY
    return Utility;
}());
